@@ -243,6 +243,8 @@ CorPlotAtomic <- function(
 #'  highlight = 'Species == "setosa"', highlight_stroke = 1.5,
 #'  anno_items = c("eq", "pearson"), anno_position = "bottomright")
 #' CorPlot(iris, "Sepal.Length", "Sepal.Width", facet_by = "Species", facet_scales = "free")
+#' CorPlot(iris, "Sepal.Length", "Sepal.Width", split_by = "Species",
+#'         palette = c(setosa = "Set1", versicolor = "Dark2", virginica = "Paired"))
 CorPlot <- function(
     data, x, y, group_by = NULL, group_by_sep = "_", group_name = NULL, split_by = NULL, split_by_sep = "_",
     pt_size = 2, pt_shape = 16, raster = FALSE, alpha = 1, raster_dpi = c(512, 512),
@@ -269,6 +271,9 @@ CorPlot <- function(
         names(datas) <- "..."
     }
 
+    palette <- check_palette(palette, names(datas))
+    palcolor <- check_palcolor(palcolor, names(datas))
+
     plots <- lapply(
         names(datas), function(nm) {
             default_title <- if (length(datas) == 1 && identical(nm, "...")) NULL else nm
@@ -283,7 +288,7 @@ CorPlot <- function(
                 highlight = highlight, highlight_color = highlight_color, highlight_size = highlight_size, highlight_alpha = highlight_alpha, highlight_stroke = highlight_stroke,
                 anno_items = anno_items, anno_size = anno_size, anno_fg = anno_fg, anno_bg = anno_bg, anno_bg_r = anno_bg_r,
                 anno_position = anno_position, add_smooth = add_smooth, smooth_color = smooth_color, smooth_width = smooth_width, smooth_se = smooth_se,
-                theme = theme, theme_args = theme_args, palette = palette, palcolor = palcolor, alpha = alpha,
+                theme = theme, theme_args = theme_args, palette = palette[[nm]], palcolor = palcolor[[nm]], alpha = alpha,
                 title = title, subtitle = subtitle, xlab = xlab, ylab = ylab,
                 facet_by = facet_by, facet_scales = facet_scales, facet_ncol = facet_ncol, facet_nrow = facet_nrow, facet_byrow = facet_byrow,
                 aspect.ratio = aspect.ratio, legend.position = legend.position, legend.direction = legend.direction, seed = seed,
@@ -445,7 +450,7 @@ CorPairsPlotAtomic <- function(
             args$data <- data
             args$x <- x
             args$group_by <- group_by
-            args$add_lines <- args$add_lines %||% FALSE
+            args$add_bars <- args$add_bars %||% FALSE
             args$palette <- args$palette %||% palette
             args$palcolor <- args$palcolor %||% palcolor
             p <- do.call(DensityPlot, args)
@@ -630,6 +635,9 @@ CorPairsPlotAtomic <- function(
 #'
 #' CorPairsPlot(data, split_by = "g", diag_type = "none", layout = ".\\",
 #'  legend.position = "bottom", legend.direction = "horizontal", group_name = "group")
+#'
+#' CorPairsPlot(data, split_by = "g",
+#'  palcolor = list("1" = "red", "2" = "blue", "3" = "green", "4" = "yellow"))
 #' }
 CorPairsPlot <- function(
     data, columns = NULL, group_by = NULL, group_by_sep = "_", group_name = NULL, split_by = NULL, split_by_sep = "_",
@@ -652,6 +660,9 @@ CorPairsPlot <- function(
         names(datas) <- "..."
     }
 
+    palette <- check_palette(palette, names(datas))
+    palcolor <- check_palcolor(palcolor, names(datas))
+
     plots <- lapply(
         names(datas), function(nm) {
             default_title <- if (length(datas) == 1 && identical(nm, "...")) NULL else nm
@@ -669,7 +680,7 @@ CorPairsPlot <- function(
                 diag_type = diag_type, diag_args = diag_args, layout = layout,
                 cor_method = cor_method, cor_palette = cor_palette, cor_palcolor = cor_palcolor,
                 cor_size = cor_size, cor_format = cor_format, cor_fg = cor_fg, cor_bg = cor_bg, cor_bg_r = cor_bg_r,
-                theme = theme, theme_args = theme_args, palette = palette, palcolor = palcolor,
+                theme = theme, theme_args = theme_args, palette = palette[[nm]], palcolor = palcolor[[nm]],
                 title = title, subtitle = subtitle, legend.position = legend.position, legend.direction = legend.direction, seed = seed,
                 ...
             )
